ChunkSchema

Type Alias ChunkSchema 

pub type ChunkSchema = Chunk;

Aliased Type

pub struct ChunkSchema {
    pub data: String,
    pub images: Vec<Uid>,
    pub char_len: usize,
    pub image_count: usize,
    pub title: String,
    pub summary: String,
    pub source: ChunkSource,
    pub uid: Uid,
    pub build_info: ChunkBuildInfo,
    pub timestamp: i64,
    pub searchable: bool,
}

Fields

data: Stringimages: Vec<Uid>char_len: usizeimage_count: usize

It’s not always images.len(). If the same image appears twice, it’s pushed only once to images but twice to image_count

title: Stringsummary: Stringsource: ChunkSourceuid: Uidbuild_info: ChunkBuildInfotimestamp: i64searchable: bool

Chunks built from rag build are always searchable. Some chunks (e.g. summary of the entire knowledge-base) have no data and must be excluded in default RAG pipeline.