pub struct BuildConfig {
pub chunk_size: usize,
pub slide_len: usize,
pub image_size: usize,
pub min_summary_len: usize,
pub max_summary_len: usize,
pub strict_file_reader: bool,
pub compression_threshold: u64,
pub compression_level: u32,
pub summary_after_build: bool,
}Fields
chunk_size: usizeIt’s not a max_chunk_size, and it’s impossible to make every chunk have the same size because
- An image cannot be splitted.
- Different files cannot be merged.
But it’s guaranteed that a chunk is never bigger than chunk_size * 2.
slide_len: usizeimage_size: usizeAn image is treated like an N characters string, and this is N.
min_summary_len: usizeIt forces the LLM to generate a summary that has at least min_summary_len characters
and at most max_summary_len characters.
max_summary_len: usizestrict_file_reader: boolIf it’s set, rag build panics if there’s any error with a file.
For example, if there’s an invalid utf-8 character PlainTextReader would die.
If it cannot follow a link of an image in a markdown file, it would die.
You don’t need this option unless you’re debugging ragit itself.
compression_threshold: u64If the .chunks file is bigger than this (in bytes), the file is compressed
compression_level: u320 ~ 9
summary_after_build: boolIf it’s set, it runs rag summary after rag build is complete.