pub struct QueryConfig {
pub max_titles: usize,
pub max_summaries: usize,
pub max_retrieval: usize,
pub enable_ii: bool,
pub enable_rag: bool,
pub super_rerank: bool,
}Fields
max_titles: usizeThis is deprecated and not used any more. It’s here for backward compatibility.
max_summaries: usizeIf there are more than this amount of chunks, it runs tf-idf to select chunks.
max_retrieval: usizeIf there are more than this amount of chunks, it runs rerank_summary prompt to select chunks.
enable_ii: boolIf it’s enabled, it uses an inverted index when running tf-idf search.
It doesn’t automatically build an inverted index when it’s missing. You
have to run rag ii-build manually to build the index.
enable_rag: boolYou can disable the entire rag pipeline. If it’s set, ragit never retrieves any chunk from the knowledge-base.
super_rerank: boolIf it’s enabled, it runs rerank_summary.pdl multiple times (usually 5 times) with much more candidates.
It takes more time and money, but is likely to yield better result.