pub struct Summary {
pub uid: Uid,
pub summary: String,
}Fields
uid: UidUid of the knowledge-base before this summary is added. Adding a summary to the knowledge-base alters the uid of the base, but it’s okay because we can get the previous uid by subtracting the uid of the summary.
summary: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Summary
impl<'de> Deserialize<'de> for Summary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Summary
impl StructuralPartialEq for Summary