pub struct Uid { /* private fields */ }Expand description
Each chunk, image and file has uid.
Uid is a 256 bit hash value, generated by sha3-256 hash function and some postprocessing.
The most convenient way for users to deal with uid is using uid_query function. The user
inputs a hex representation of a uid, or a prefix of it, and the function returns
matched uids.
The first 192 bits (128 of high + 64 of low) are from the hash function, and
the remaining bits are for metadata.
Implementations
Sourceimpl Uid
impl Uid
pub fn decode(bytes: &[u8]) -> Result<Self, Error>
pub fn encode(&self, buffer: &mut Vec<u8>)
pub fn new_chunk(chunk: &Chunk) -> Self
pub fn new_image(bytes: &[u8]) -> Self
pub fn new_file(root_dir: &str, path: &str) -> Result<Self, Error>
pub fn new_group(uids: &[Uid]) -> Self
pub fn new_knowledge_base(uids: &[Uid]) -> Self
pub fn new_summary(summary: &str) -> Self
pub fn new_query_turn(turn: &QueryTurn) -> Self
pub fn update_file_uid(old: Uid, old_path: &str, new_path: &str) -> Self
pub fn get_prefix(&self) -> String
pub fn get_suffix(&self) -> String
Sourcepub fn abbrev(&self, n: usize) -> String
pub fn abbrev(&self, n: usize) -> String
It returns the first n characters of the uid.
It returns the full uid if n is greater than or equal to 64.
pub fn is_valid_prefix(s: &str) -> bool